@@ -51,7 +51,7 @@ class TuskHandler(Handler):
         stacktrace_column = config.get_stacktrace_column()
         if stacktrace_column is not None:
             stacktrace = ''
-            if record.exc_info is not None:
+            if record.exc_info:
                 lines = traceback.format_exception(*record.exc_info)
                 stacktrace = ''.join(lines)
             key_values[stacktrace_column] = stacktrace
